@@ -6,7 +6,7 @@
 
 package Module::TestConfig;
 
-require 5.005_62;
+require 5.008;
 use strict;
 use Carp;
 use Fcntl;
@@ -21,8 +21,7 @@ use Module::TestConfig::Question;
 #   Term::ReadKey;
 #   File::Path
 
-use vars qw/$VERSION/;
-$VERSION = '0.04';
+our $VERSION = '0.05';
 
 #------------------------------------------------------------
 # Methods
@@ -250,6 +249,17 @@ sub save {
 	. $self->report if $self->{verbose};
 }
 
+# Error in v.04:
+#
+#   Failed test 'save_defaults()'
+#   at t/40_defaults.t line 40.
+# found warning: Filehandle STDIN reopened as F only for output at /home/sand/.cpan/build/Module-TestConfig-0.04-pvLCvJ/blib/lib/Module/TestConfig.pm line 263.
+# found carped warning: Skipping bad key with a separator in it: 'bro:ken' at t/40_defaults.t line 39
+# expected to find carped warning: /^Skipping bad key/
+# Looks like you failed 1 test of 28.
+#
+# We're going to ignore that STDIN warning here - ignoring it in t/40_defaults.t does nothing.
+
 sub save_defaults {
     my $self = shift;
     my %args = ( file => $self->{defaults},
@@ -260,11 +270,14 @@ sub save_defaults {
     # doesn't matter if this fails:
     rename $args{file}, "$args{file}.bak" if -e $args{file};
 
+	no warnings "io";
+
     open  F, "> $args{file}"
         or carp ("Unable to write to $args{file}: $!"), return;
 
-    print F "# This defaults file was autogenerated by "
-	. "Module::TestConfig for $self->{package}\n\n";
+	use warnings "io";
+
+    print F "# This defaults file was autogenerated by Module::TestConfig for $self->{package}\n\n";
 
     while ( my ($k, $v) = each %{ $self->{answers} } ) {
 	carp ("Skipping bad key with a separator in it: '$k'"), next
